@@ -84,6 +84,28 @@ class DocManager(DocManagerBase):
                         tx.run(self.creat_relationship(id, id_, type,program_id))
         tx.commit()
 
+    def update(self, document_id, update_spec, namespace, timestamp):
+        pass
+
+    def remove(self, document_id, namespace, timestamp):
+        """Removes a document from Neo4j."""
+        doc_id = u(document_id)
+        tx = self.graph.begin()
+        statement = "MATCH (d:Document) WHERE d._id={} OPTIONAL MATCH (d)-[r]-() DELETE d, r".format(doc_id)
+        tx.run(statement)
+        tx.commit()
+
+    def search(self, start_ts, end_ts):
+        statement = "MATCH (d:Document) WHERE d._ts>={start_ts} AND d._ts<={end_ts} RETURN d".format(start_ts=start_ts, end_ts=end_ts)
+        results = self.graph.run(statement)
+        return results
+
+    def get_last_doc(self):
+        """Get the most recently modified node from Neo4j.
+        This method is used to help define a time window within which documents
+        may be in conflict after a MongoDB rollback.
+        """
+        LOG.error("Commit")
 
     def commit(self):
         LOG.error("Commit")
